package com.uas.ps.inquiry;

import com.uas.ps.core.util.CollectionUtils;
import com.uas.ps.inquiry.dao.CronDao;
import com.uas.ps.inquiry.model.Cron;
import com.uas.ps.inquiry.model.InquiryRemind;
import com.uas.ps.inquiry.service.impl.InquiryServiceImpl;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.Trigger;
import org.springframework.scheduling.TriggerContext;
import org.springframework.scheduling.annotation.SchedulingConfigurer;
import org.springframework.scheduling.config.ScheduledTaskRegistrar;
import org.springframework.scheduling.support.CronTrigger;
import org.springframework.util.StringUtils;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * created by shicr on 2018/6/8
 **/
@Configuration
public class SchedulingConfig implements SchedulingConfigurer {

    private final Logger logger = LoggerFactory.getLogger(SchedulingConfig.class);

    private static final SimpleDateFormat DATE_FORMAT = new SimpleDateFormat("HH:mm:ss");

    @Autowired
    private CronDao cronDao;

    private String cornStr = "";

    @Autowired
    private InquiryServiceImpl service;

    @Override
    public void configureTasks(ScheduledTaskRegistrar scheduledTaskRegistrar) {


        scheduledTaskRegistrar.addTriggerTask(new Runnable() {


            @Override
            public void run() {
                Cron cron = cronDao.findOne(1L);
                List<InquiryRemind> reminds = new ArrayList<>();
                logger.info("动态修改定时任务cron参数，当前时间：" + DATE_FORMAT.format(new Date()));
                if(null != cron.getCron() && cron.getStartTime() != null && cron.getEndTime() != null && cron.getEnuu() != null && cron.getUseruu() != null){
                    reminds = service.testMessage(cron.getStartTime(), cron.getEndTime(), cron.getUseruu(),cron.getEnuu());
//                    reminds = service.findInquiryRemindGroupByVendUUAndVendUserUU(5);
                }

                if(!CollectionUtils.isEmpty(reminds)){
                    service.sendMessage(reminds.size(), reminds);
                }
            }
        }, new Trigger() {
            @Override
            public Date nextExecutionTime(TriggerContext triggerContext) {
                Cron cron = cronDao.findOne(1L);
                if (cron != null && !StringUtils.isEmpty(cron.getCron())) {
                    cornStr = cron.getCron();
                }
                CronTrigger trigger = new CronTrigger(cron.getCron());
                Date nextExecDate = trigger.nextExecutionTime(triggerContext);
                logger.info("下次执行自动推送时间： " + DATE_FORMAT.format(nextExecDate));
                return nextExecDate;
            }
        });
    }


}