package com.uas.ps.inquiry.controller;

import com.uas.ps.core.util.ContextUtils;
import com.uas.ps.inquiry.AccessConfiguration;
import com.uas.ps.inquiry.dao.EnterpriseDao;
import com.uas.ps.inquiry.dao.InquiryDataDao;
import com.uas.ps.inquiry.dao.PurcInquiryItemDao;
import com.uas.ps.inquiry.entity.MessageModel;
import com.uas.ps.inquiry.model.Enterprise;
import com.uas.ps.inquiry.model.InquiryData;
import com.uas.ps.inquiry.model.InquiryRemind;
import com.uas.ps.inquiry.model.PublicInquiryItem;
import com.uas.ps.inquiry.rabbit.MessageInfo;
import com.uas.ps.inquiry.rabbit.RabbitConstants;
import com.uas.ps.inquiry.service.InquiryService;
import com.uas.ps.inquiry.util.FlexJsonUtils;
import com.uas.ps.inquiry.util.ThreadUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.amqp.rabbit.support.CorrelationData;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import java.util.*;

/**
 * 求购截止，每日晚上轮询一次
 *
 * @version 2018年6月12日 15:00  询价短信定时发送的任务移到这里  dongbw
 */
@Component
public class DeadlineTask {
    @Autowired
    private PurcInquiryItemDao purcInquiryItemDao;

    @Autowired
    private EnterpriseDao enterpriseDao;

    @Autowired
    private InquiryService inquiryService;

    @Autowired
    private JdbcTemplate jdbcTemplate;

    @Autowired
    private InquiryDataDao inquiryDataDao;

    @Autowired
    private RabbitTemplate rabbitTemplate;

    private static final Logger log = LoggerFactory.getLogger(DeadlineTask.class);

    /**
     * 消息类型，公共询价的采纳结果
     */
    private final String INQUIRY_DECIDE_TYPE_MALL = "商城公共询价采纳结果";

    /**
     * 接收应用
     */
    private final String CONSUMERAPP_B2B_MALL = "B2B,MALL";

    /**
     * 应用来源，主要是为了平台公共询价做处理
     */
    private String SOURCEAPP_MALL = "MALL";

    /**
     * 消息类型 （在B2B消息中拼接跳转单据详情url请求时需要）
     */
    private final String INQUIRY_TYPE = "公共询价";

    /**
     * 消息推送短信模板id
     */
    private final String SMS_TEMP_ID = "e6320a3c-89ac-4c77-a75f-62a727bce654";

    /**
     * 消息推送方式：邮件、短信、im
     */
    private final String SMS_TYPE = "MAIL_AND_SM_AND_IM";

    /**
     * 消费类型： 多个，MULTI
     */
    private final String CUST_TYPE = "MULTI";

    /**
     * 接收应用
     */
    private final String CONSUMERAPP_HIDE = "HIDE";

    /**
     * 消息类型 （在MALL消息中拼接求购询价待报价）
     */
    private final String INQUIRY_TYPE_SELLER_MALL = "MALL跳转卖家待报价页面";

    /**
     * 询价统计通知发送人UU
     */
    private final Long MESSAGE_SENDERUU = ContextUtils.getBean(AccessConfiguration.class).getSenderuu();

    /**
     * 询价统计通知发送企业UU
     */
    private final Long MESSAGE_SENDERENUU = ContextUtils.getBean(AccessConfiguration.class).getSenderEnuu();

    /**
     * 每天晚上十一点半对未操作的过期单据，发送消息提醒
     */
    @Scheduled(cron = "0 30 23 ? * *")
    public void execute() {
        List<PublicInquiryItem> d = purcInquiryItemDao.findendDate();
        for (PublicInquiryItem param : d) {
                //发送信息
            final String SMS_TYPE = "SM";
            List<MessageModel> models = new ArrayList<MessageModel>();
            String cmpCode = param.getCmpCode();
            String cmp = cmpCode.length() > 10 ? cmpCode.substring(0, 10).concat("...") : cmpCode;
            String content = param.getInquiry().getEnName() + "关于“型号：" + cmp + "“的求购【已截止】，您的报价尚未被采纳。";
            MessageModel model = new MessageModel();
            model.setType(INQUIRY_DECIDE_TYPE_MALL);
            model.setProducerApp(SOURCEAPP_MALL);
            model.setConsumerType(CUST_TYPE);
            model.setConsumerApp(CONSUMERAPP_B2B_MALL);
            model.setContent(content);
            model.setRemark(String.valueOf(param.getInquiry().getId()));
            model.setSourceId(param.getId());
            model.setReceiverEnuu(param.getVendUU());
            model.setReceiverUu(param.getVendUserUU());
            model.setSenderEnuu(param.getInquiry().getEnUU());
            if (null != param.getUserUU() || null != param.getInquiry().getRecorderUU()) {
                model.setSenderUu(param.getUserUU() != null ? param.getUserUU() : param.getInquiry().getRecorderUU());
            } else {
                Enterprise enterprise = enterpriseDao.findOne(param.getInquiry().getEnUU());
                model.setSenderUu(null != enterprise ? enterprise.getAdminUU() : 0L);
            }
            model.setSmsType(SMS_TYPE);
            models.add(model);
            if (!CollectionUtils.isEmpty(models)) {
                sendMessage(models);
            }

        }
    }

    /**
     * 发送消息推送
     *
     * @param models 封装的消息信息
     */
    private void sendMessage(final List<MessageModel> models) {
        ThreadUtils.task(new Runnable() {
            @Override
            public void run() {
                try {
                    long start = System.currentTimeMillis();
                    log.info("发送消息");

                    //设置消息ID
                    MessageInfo messageInfo = new MessageInfo();
                    messageInfo.setMsgId(UUID.randomUUID().toString());
                    //设置时间戳
                    messageInfo.setTimestamp(System.currentTimeMillis());
                    messageInfo.setData(models);
                    CorrelationData correlationData = new CorrelationData(messageInfo.getMsgId());
                    rabbitTemplate.convertAndSend(RabbitConstants.AMQ_DIRECT, RabbitConstants.INQUIRY_MESSAGE_ROUTINGKEY, messageInfo, correlationData);

                    log.info("公共询价, 定时发动消息: {}, 耗时: {}", models.size(), (System.currentTimeMillis() - start));
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        });
    }

    /**
     * 每早9点、14点、17点发送询价通知短信
     */
    @Scheduled(cron = "0 0 9,14,17 * * ?")
    private void sendMessageTiming() throws Exception {
        Calendar now = Calendar.getInstance();
        Integer hour = now.get(Calendar.HOUR_OF_DAY);
        log.info("{}点定时统计询价单总数服务开启", hour);
        List<InquiryRemind> reminds = new ArrayList<>();
        switch (hour) {
            case 9:
                reminds = inquiryService.findInquiryRemindGroupByVendUUAndVendUserUU(16);
                break;
            case 14:
                reminds = inquiryService.findInquiryRemindGroupByVendUUAndVendUserUU(5);
                break;
            case 17:
                reminds = inquiryService.findInquiryRemindGroupByVendUUAndVendUserUU(3);
                break;
            default:
                break;
        }

        if (!CollectionUtils.isEmpty(reminds)) {
            inquiryService.sendMessage(reminds);
        }
        log.info("{}点定时统计询价单总数服务结束", hour);
    }

    /**
     * 每天0时 查询询价数据
     */
    @Scheduled(cron = "0 0 0 * * ?")
    public void inquiryDataQuery() {
        List<InquiryData> inquiryDataList = inquiryDataDao.findAll();
        long start = System.currentTimeMillis();
        String sql = "";
        List<Map<String, Object>> data = null;
        String jsonData = "";
        for (InquiryData inquiryData : inquiryDataList) {
            sql = inquiryData.getSql();
            data = jdbcTemplate.queryForList(sql);
            jsonData = FlexJsonUtils.toJson(data);
            inquiryData.setData(jsonData);
            System.out.println(jsonData);
            inquiryDataDao.save(inquiryData);
        }
        log.info("公共询价, 查询询价数据: {}, 耗时: {}", jsonData, (System.currentTimeMillis() - start));
    }
}
