package com.uas.ps.inquiry.controller;

import com.uas.ps.inquiry.service.PublicInquiryService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import java.util.Date;
import java.util.HashMap;

/**
 * 询价服务供其他应用调用的接口
 *
 * @author dongbw
 */
@RequestMapping(value = "/inquiry/api")
@RestController
public class PublicApiController {

    @Autowired
    private PublicInquiryService publicInquiryService;

    private final static Logger log = LoggerFactory.getLogger(PublicApiController.class);

    /**
     * 查询个人不同型号发布询价数量统计
     * @param enuu 企业uu
     * @param useruu  用户uu
     * @param starttime  开始时间
     * @param endtime  结束时间
     * @return 数量结果
     */
    @RequestMapping(value = "/sum/publish/personal", method = RequestMethod.GET)
    public ModelMap sumPersonalPublish(Long enuu, Long useruu, Long starttime, Long endtime) {
        long start = System.currentTimeMillis();
        log.info("/api/sum/publish/personal get 参数：enuu: {}, useruu: {}, starttime: {}, endtime: {}",
                enuu, useruu, new Date(starttime), new Date(endtime));
        ModelMap map = publicInquiryService.sumPersonalPublish(enuu, useruu, starttime, endtime);
        log.info("/api/sum/publish/personal get 耗时: {}", (System.currentTimeMillis() - start));
        return map;
    }

    /**
     * 查询企业不同型号发布询价数量统计
     * @param enuu 企业uu
     * @param starttime  开始时间
     * @param endtime  结束时间
     * @return
     */
    @RequestMapping(value = "/sum/publish/enterprise", method = RequestMethod.GET)
    public ModelMap sumEnterprisePublish(Long enuu, Long starttime, Long endtime) {
        long start = System.currentTimeMillis();
        log.info("/api/sum/publish/enterprise get 参数：enuu: {}, starttime: {}, endtime: {}",
                enuu, new Date(starttime), new Date(endtime));
        ModelMap map = publicInquiryService.sumEnterprisePublish(enuu, starttime, endtime);
        log.info("/api/sum/publish/enterprise get 耗时: {}", (System.currentTimeMillis() - start));
        return map;
    }

    /**
     * 查询个人回复询价数量统计
     * @param enuu 企业uu
     * @param useruu  用户uu
     * @param starttime  开始时间
     * @param endtime  结束时间
     * @return
     */
    @RequestMapping(value = "/sum/reply/personal", method = RequestMethod.GET)
    public ModelMap sumPersonalReply(Long enuu, Long useruu, Long starttime, Long endtime) {
        long start = System.currentTimeMillis();
        log.info("/api/sum/reply/personal get 参数：enuu: {}, useruu: {}, starttime: {}, endtime: {}",
                enuu, useruu, new Date(starttime), new Date(endtime));
        ModelMap map = publicInquiryService.sumPersonalReply(enuu, useruu, starttime, endtime);
        log.info("/api/sum/reply/personal get 耗时: {}", (System.currentTimeMillis() - start));
        return map;
    }

    /**
     * 查询企业回复询价数量统计
     * @param enuu 企业uu
     * @param starttime  开始时间
     * @param endtime  结束时间
     * @return
     */
    @RequestMapping(value = "/sum/reply/enterprise", method = RequestMethod.GET)
    public ModelMap sumEnterpriseReply(Long enuu, Long starttime, Long endtime) {
        long start = System.currentTimeMillis();
        log.info("/api/sum/reply/enterprise get 参数：enuu: {}, starttime: {}, endtime: {}",
                enuu, new Date(starttime), new Date(endtime));
        ModelMap map = publicInquiryService.sumEnterpriseReply(enuu, starttime, endtime);
        log.info("/api/sum/reply/enterprise get 耗时: {}", (System.currentTimeMillis() - start));
        return map;
    }

    /**
     * 获取今天和昨天的询价和报价统计
     * @param time 时间
     * @return 统计结果
     */
    @RequestMapping(value = "/sum/all/time", method = RequestMethod.GET)
    public HashMap<String, Object> sumRecentPublishWithTime(Long time) throws Exception {
        long start = System.currentTimeMillis();
        log.info("/api/sum/all/time get 参数：time{}", new Date(time));
        HashMap<String, Object> map = publicInquiryService.sumRecentPublishWithTime(time);
        log.info("/api/sum/all/time get 耗时: {}", (System.currentTimeMillis() - start));
        return map;
    }

    /**
     * 获取区间时间内的询价和报价统计
     * @param starttime 起始时间
     * @param endtime 起始时间
     * @return 统计结果
     */
    @RequestMapping(value = "/sum/all/scope", method = RequestMethod.GET)
    public ModelMap sumPublishWithTimeScope(Long starttime, Long endtime) throws Exception {
        long start = System.currentTimeMillis();
        log.info("/api/sum/all/scope get 参数：starttime{}, endtime:{}", new Date(starttime), new Date(endtime));
        ModelMap map = publicInquiryService.sumPublishWithTimeScope(starttime, endtime);
        log.info("/api/sum/all/scope get 耗时: {}", (System.currentTimeMillis() - start));
        return map;
    }

    /**
     * 根据企业UU查询发布询价条数
     * @param enuu 企业UU
     * @return
     */
    @RequestMapping(value = "/sum/enuu", method = RequestMethod.GET)
    public ModelMap sumCountWithEnuu(Long enuu) {
        long start = System.currentTimeMillis();
        log.info("/api/sum/enuu get 参数：enuu:{}",enuu);
        ModelMap map = publicInquiryService.sumCountWithEnuu(enuu);
        log.info("/api/sum/enuu get 耗时: {}", (System.currentTimeMillis() - start));
        return map;
    }
}
