package com.uas.ps.inquiry.model;

import javax.persistence.*;
import java.io.Serializable;
import java.util.Date;

/**
 * 针对用户的询价企业推荐提醒
 *
 * Created by lisuw on 2018-01-31.
 */
@Entity
@Table(name = "purc$inquiry$enremind")
public class InquiryEnRemind implements Serializable {

    /**
     * default serialVersionUID
     */
    private static final long serialVersionUID = 1L;

    /**
     * id
     */
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Column(name = "ir_id")
    private Long id;

    /**
     * 询价单号
     */
    @Column(name = "ir_code")
    private String code;

    /**
     * 询价企业名称
     */
    @Column(name = "ir_enname")
    private String enName;

    /**
     * 询价企业UU
     */
    @Column(name = "ir_enuu")
    private Long enUU;

    /**
     * 联系人
     */
    @Column(name = "ir_username")
    private String userName;

    /**
     * 联系方式
     */
    @Column(name = "ir_usertel")
    private String userTel;

    /* ********************* 物料信息start***************************** */

    /**
     * 询价品牌
     */
    @Column(name = "ir_brand")
    private String brand;

    /**
     * 询价品牌
     */
    @Column(name = "ir_inbrand")
    private String inbrand;

    /**
     * 原厂型号
     */
    @Column(name = "ir_cmpcode")
    private String cmpCode;

    /**
     * 物料规格
     */
    @Column(name = "ir_spec")
    private String spec;

    /**
     * 物料名称
     */
    @Column(name = "ir_title")
    private String prodTitle;

    /* ********************* 物料信息end***************************** */

    /**
     * 需求数量
     */
    @Column(name = "ir_needqty")
    private Double needQty;

    /**
     * 发布日期
     */
    @Column(name = "ir_redate")
    private Date reDate;

    /**
     * 截止日期
     */
    @Column(name = "ir_endate")
    private Date endDate;

    /**
     * 记录来源公共询价询价明细id
     */
    @Column(name = "ir_itemid")
    private Long itemId;

    /**
     * 记录来源公共询价询价单id
     */
    @Column(name = "ir_inid")
    private Long inid;

    /**
     * 询价单信息
     */
    @OneToOne
    @JoinColumn(name = "ir_inid", insertable = false, updatable = false)
    private PurcInquiry inquiry;

    /**
     * 记录转报价后的明细id
     */
    @Column(name = "ir_newid")
    private Long newId;

    /**
     * 单据状态
     * <note>
     * {@code 100 在录入}
     * {@code 101 已提交}
     * {@code 102 已审核}
     * {@code 103 未通过}
     * {@code 104 已通过}
     * </note>
     */
    @Column(name = "ir_status")
    private Integer status;

    /**
     * 被推荐的企业UU
     */
    @Column(name = "ir_venduu")
    private Long vendUU;

//    /**
//     * 被推荐的人员UU
//     */
//    @Column(name = "ir_venduseruu")
//    private Long vendUserUU;

    /**
     * 是否已包含在个人商机 1是  0 否
     */
    @Column(name = "ir_remindstatus")
    private Integer remindStatus;

    /**
     * 记录日期
     */
    @Column(name = "ir_date")
    private Date date;

    /**
     * 剩余时间
     */
    @Transient
    private Long remainingTime;

    /**
     * 报价单详情
     */
    @Transient
    private PublicInquiryItem quotation;

    /**
     * erp下载状态 202  待上传 203 已下载
     */
    @Column(name = "ir_erpdownstatus", columnDefinition = "smallint default 202")
    private Short erpDownStatus = 202;

    public String getInbrand() {
        return inbrand;
    }

    public void setInbrand(String inbrand) {
        this.inbrand = inbrand;
    }

    public Long getRemainingTime() {
        if (null != endDate) {
            return endDate.getTime() - System.currentTimeMillis();
        }
        return null;
    }

    public Long getInid() {
        return inid;
    }

    public void setInid(Long inid) {
        this.inid = inid;
    }

    public PurcInquiry getInquiry() {
        return inquiry;
    }

    public void setInquiry(PurcInquiry inquiry) {
        this.inquiry = inquiry;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getEnName() {
        return enName;
    }

    public void setEnName(String enName) {
        this.enName = enName;
    }

    public Long getEnUU() {
        return enUU;
    }

    public void setEnUU(Long enUU) {
        this.enUU = enUU;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getUserTel() {
        return userTel;
    }

    public void setUserTel(String userTel) {
        this.userTel = userTel;
    }

    public String getBrand() {
        return brand;
    }

    public void setBrand(String brand) {
        this.brand = brand;
    }

    public String getCmpCode() {
        return cmpCode;
    }

    public void setCmpCode(String cmpCode) {
        this.cmpCode = cmpCode;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public String getProdTitle() {
        return prodTitle;
    }

    public void setProdTitle(String prodTitle) {
        this.prodTitle = prodTitle;
    }

    public Double getNeedQty() {
        return needQty;
    }

    public void setNeedQty(Double needQty) {
        this.needQty = needQty;
    }

    public Date getReDate() {
        return reDate;
    }

    public void setReDate(Date reDate) {
        this.reDate = reDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public Long getNewId() {
        return newId;
    }

    public void setNewId(Long newId) {
        this.newId = newId;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Long getVendUU() {
        return vendUU;
    }

    public void setVendUU(Long vendUU) {
        this.vendUU = vendUU;
    }

    public Date getDate() {
        return date;
    }

    public void setDate(Date date) {
        this.date = date;
    }

    public Integer getRemindStatus() {
        return remindStatus;
    }

    public void setRemindStatus(Integer remindStatus) {
        this.remindStatus = remindStatus;
    }

    public void setRemainingTime(Long remainingTime) {
        this.remainingTime = remainingTime;
    }

    public PublicInquiryItem getQuotation() {
        return quotation;
    }

    public void setQuotation(PublicInquiryItem quotation) {
        this.quotation = quotation;
    }

    public Short getErpDownStatus() {
        return erpDownStatus;
    }

    public void setErpDownStatus(Short erpDownStatus) {
        this.erpDownStatus = erpDownStatus;
    }
}
