package com.uas.ps.inquiry.rabbit;

import org.springframework.amqp.core.AmqpAdmin;
import org.springframework.amqp.core.Binding;
import org.springframework.amqp.core.DirectExchange;
import org.springframework.amqp.core.Queue;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.amqp.support.converter.Jackson2JsonMessageConverter;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Configuration;

import javax.annotation.PostConstruct;

/**
 * rabbit 配置
 * @author liuam
 * @since 2018/9/11 0011 下午 16:30
 */
@Configuration
public class RabbitConfig {


    @Autowired
    private RabbitTemplate rabbitTemplate;

    @Autowired
    private RabbitConfirmCallback rabbitConfirmCallback;

    @Autowired
    private AmqpAdmin amqpAdmin;

    @PostConstruct
    public void init() {
//      如果消息没有到exchange,则confirm回调,ack=false
//		如果消息到达exchange,则confirm回调,ack=true
//		exchange到queue成功,则不回调return
//		exchange到queue失败,则回调return(否则不回回调,消息就丢了)
        rabbitTemplate.setMessageConverter(new Jackson2JsonMessageConverter());
        rabbitTemplate.setConfirmCallback(rabbitConfirmCallback);
        rabbitTemplate.setReturnCallback(rabbitConfirmCallback);

        amqpAdmin.declareExchange(new DirectExchange(RabbitConstants.AMQ_DIRECT, true, false, null));
        amqpAdmin.declareQueue(new Queue(RabbitConstants.INQUIRY_MESSAGE));
        amqpAdmin.declareQueue(new Queue(RabbitConstants.INQUIRY_PRODUCT));

        amqpAdmin.declareBinding(new Binding(RabbitConstants.INQUIRY_MESSAGE, Binding.DestinationType.QUEUE, RabbitConstants.AMQ_DIRECT, RabbitConstants.INQUIRY_MESSAGE_ROUTINGKEY, null));
        amqpAdmin.declareBinding(new Binding(RabbitConstants.INQUIRY_PRODUCT, Binding.DestinationType.QUEUE, RabbitConstants.AMQ_DIRECT, RabbitConstants.INQUIRY_PRODUCT_ROUTINGKEY, null));
    }


}
