package com.uas.ps.inquiry.controller;

import com.alibaba.fastjson.JSON;
import com.uas.ps.inquiry.BaseJunitTest;
import com.uas.ps.inquiry.entity.Constant;
import com.uas.ps.inquiry.page.PageInfo;
import com.uas.ps.inquiry.page.SearchFilter;
import com.uas.ps.inquiry.util.FlexJsonUtils;
import com.uas.ps.inquiry.util.HttpUtil;
import org.junit.Test;
import org.springframework.test.web.servlet.RequestBuilder;

import java.util.HashMap;

import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.get;

/**
 * @author dongbw
 * @since 2018年9月27日
 */
public class PublicInquiryControllerTest extends BaseJunitTest {

    /**
     * localhost
     */
    private static final String localhost = "http://10.1.51.82:24002";

    /**
     * dev
     */
    private static final String dev_url = "http://192.168.253.12:24000";

    /**
     * userUU
     */
    private static final Long userUU = 1000002503L;

    /**
     * enUU
     */
    private static final Long enUU = 10041166L;

    /**
     * /
     */
    @Test
    public void testGetInquiry() throws Exception {
        SearchFilter searchFilter = new SearchFilter();
        searchFilter.setEnUU(1001166L);
        searchFilter.setUserUU(1000002503L);
        PageInfo pageInfo = new PageInfo(1, 20);
        HashMap<String, Object> params = new HashMap<>();
        params.put("pageInfo", pageInfo);
        params.put("searchFilter", searchFilter);
        HttpUtil.Response res = HttpUtil.sendGetRequest(localhost + "/inquiry/public", params);
        System.out.println(FlexJsonUtils.toJson(res));
    }

    /**
     * inquiryList
     * @throws Exception
     */
    @Test
    public void testGetInquiryList() throws Exception {
        SearchFilter searchFilter = new SearchFilter();
        searchFilter.setEnUU(1001166L);
        searchFilter.setUserUU(1000002503L);
        PageInfo pageInfo = new PageInfo(1, 20);
        HashMap<String, Object> params = new HashMap<>();
        params.put("pageInfo", pageInfo);
        params.put("searchFilter", searchFilter);
        HttpUtil.Response res = HttpUtil.sendGetRequest(localhost + "/inquiry/public/inquiryList", params);
        System.out.println(FlexJsonUtils.toJson(res));
    }

    /**
     * /quotation/list
     * @throws Exception
     */
    @Test
    public void testGetQuotation() throws Exception {
        SearchFilter filter = new SearchFilter();
        filter.setEnUU(1001166L);
        filter.setUserUU(1000002503L);
        PageInfo pageInfo = new PageInfo(1, 20);
        HashMap<String, Object> params = new HashMap<>();
        params.put("pageInfo", pageInfo);
        params.put("filter", JSON.toJSON(filter));
        params.put("overdue", Constant.NO);
        params.put("_state", "done");
        HttpUtil.Response res = HttpUtil.sendGetRequest(localhost + "/inquiry/public/quotation/list", params);
        System.out.println(FlexJsonUtils.toJson(res));
    }

    /**
     * /quotation/one
     * @throws Exception
     */
    @Test
    public void testGetQuotationById() throws Exception {
        HashMap<String, Object> params = new HashMap<>();
        params.put("id", 223L);
        params.put("useruu", userUU);
        params.put("enuu", enUU);
        HttpUtil.Response res = HttpUtil.sendGetRequest(localhost + "/inquiry/public/quotation/one", params);
        System.out.println(FlexJsonUtils.toJson(res));
    }

    /**
     * /quotationList
     * @throws Exception
     */
    @Test
    public void testGetQuotationList() throws Exception {
        SearchFilter filter = new SearchFilter();
        filter.setEnUU(1001166L);
        filter.setUserUU(1000002503L);
        PageInfo pageInfo = new PageInfo(1, 20);
        HashMap<String, Object> params = new HashMap<>();
        params.put("pageInfo", pageInfo);
        params.put("searchFilter", JSON.toJSON(filter));
        params.put("overdue", Constant.NO);
        params.put("_state", "agreed");

        RequestBuilder request= get("/inquiry/public/quotationList")
                .requestAttr("pageInfo", pageInfo).requestAttr("filter", filter)
                .requestAttr("overdue", Constant.NO).requestAttr("_state", "agreed");
        System.out.println(mockMvc.perform(request).andReturn().getResponse().getContentAsString());
    }

    /**
     * /messageList
     * @throws Exception
     */
    @Test
    public void testGetList() throws Exception {
        HashMap<String, Object> params = new HashMap<>();
        params.put("size", 20);
        params.put("enuu", enUU);
        HttpUtil.Response res = HttpUtil.sendGetRequest(localhost + "/inquiry/public/messageList", params);
        System.out.println(FlexJsonUtils.toJson(res));
    }

    /**
     * /attachUrl
     * @throws Exception
     */
    @Test
    public void testGetAttach() throws Exception {
        HashMap<String, Object> params = new HashMap<>();
        params.put("id", 20);
        HttpUtil.Response res = HttpUtil.sendGetRequest(localhost + "/inquiry/public/attachUrl", params);
        System.out.println(FlexJsonUtils.toJson(res));
    }

    /**
     * /findInquiryById
     * @throws Exception
     */
    @Test
    public void testFindById() throws Exception {
        HashMap<String, Object> params = new HashMap<>();
        params.put("id", 20L);
        params.put("enuu", enUU);
        HttpUtil.Response res = HttpUtil.sendGetRequest(localhost + "/inquiry/public/findInquiryById", params);
        System.out.println(FlexJsonUtils.toJson(res));
    }


    /**
     * /findCodeRankingList
     * @throws Exception
     */
    @Test
    public void testFindCodeRankingList() throws Exception {
        HashMap<String, Object> params = new HashMap<>();
        HttpUtil.Response res = HttpUtil.sendGetRequest(localhost + "/inquiry/public/findCodeRankingList", null);
        System.out.println(FlexJsonUtils.toJson(res));
    }

    /**
     * /findItemByItemId
     * @throws Exception
     */
    @Test
    public void testFindItemByItemId() throws Exception {
        HashMap<String, Object> params = new HashMap<>();
        params.put("itemId", 1220L);
        params.put("enuu", enUU);
        HttpUtil.Response res = HttpUtil.sendGetRequest(localhost + "/inquiry/public/findItemByItemId", params);
        System.out.println(FlexJsonUtils.toJson(res));
    }

    /**
     * /getPurcInquiryItemCount
     * @throws Exception
     */
    @Test
    public void testGetPurcInquiryItemCount() throws Exception {
        HashMap<String, Object> params = new HashMap<>();
        HttpUtil.Response res = HttpUtil.sendGetRequest(localhost + "/inquiry/public/getPurcInquiryItemCount",
                null);
        System.out.println(FlexJsonUtils.toJson(res));
    }

    /**
     * /getPurcInquiryItemCountByMonth
     * @throws Exception
     */
    @Test
    public void testGetPurcInquiryItemCountByMonth() throws Exception {
        HashMap<String, Object> params = new HashMap<>();
        params.put("year", 2018);
        params.put("month", 9);
        HttpUtil.Response res = HttpUtil.sendGetRequest(localhost + "/inquiry/public/getPurcInquiryItemCountByMonth", params);
        System.out.println(FlexJsonUtils.toJson(res));
    }

    /**
     * /getCountOfLastAndThisMonth
     * @throws Exception
     */
    @Test
    public void testGetCountOfLastAndThisMonth() throws Exception {
        HttpUtil.Response res = HttpUtil.sendGetRequest(localhost + "/inquiry/public/getCountOfLastAndThisMonth", null);
        System.out.println(FlexJsonUtils.toJson(res));
    }

    /**
     * /deleteItem
     * @throws Exception
     */
    @Test
    public void testDeleteItems() throws Exception {
        HashMap<String, Object> params = new HashMap<>();
        params.put("id", 1220);
        params.put("valid", Constant.NO);
        String res = HttpUtil.doPost(localhost + "/inquiry/public/deleteItem", null);
        System.out.println(res);
    }

    /**
     * /getInquiryCountData
     * @throws Exception
     */
    @Test
    public void testGetInquiryCountData() throws Exception {
        HashMap<String, Object> params = new HashMap<>();
        params.put("startDate", "2018-09-30 00:00:00");
        params.put("endDate", "2018-10-30 00:00:00");
        HttpUtil.Response res = HttpUtil.sendGetRequest(localhost + "/inquiry/public/getInquiryCountData",
                params);
        System.out.println(FlexJsonUtils.toJson(res));
    }
}
